==> ejc-ztjpoc-api-3.0.0-20210729.085935-45-sources.jar: com/ejianc/poc/vo/OrgVO.java <==
package com.ejianc.poc.vo;

/**
 * @author CJ
 * @Description:
 * @date 2021/4/14 16:55
 */
public class OrgVO extends BaseFieldVO {

    public static final Long rootOrgId = -999999L;
    public static final String rootOrgCode = "root_org_code";
    private static final long serialVersionUID = 9162261826184960936L;

    public static OrgVO rootOrg;

    /**
     *
     * 单位全称
     */
    private String fullName;
    /**
     * 单位code
     */
    private String code;

    /**
     * 是否在组织机构路径中显示
     */
    private Boolean show;
    /**
     * 是否虚拟组织机构
     */
    private Boolean virtual;

    /**
     * 父级单位Id
     */
    private String pid;

    public String getPid() {
        return pid;
    }

    public void setPid(String pid) {
        this.pid = pid;
    }

    public String getFullName() {
        return fullName;
    }

    public void setFullName(String fullName) {
        this.fullName = fullName;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Boolean getShow() {
        return show;
    }

    public void setShow(Boolean show) {
        this.show = show;
    }

    public Boolean getVirtual() {
        return virtual;
    }

    public void setVirtual(Boolean virtual) {
        this.virtual = virtual;
    }

    public static OrgVO getRootOrg() {
        if(null != rootOrg) {
            return rootOrg;
        }

        rootOrg = new OrgVO();
        rootOrg.setCode(rootOrgCode);
        rootOrg.setId(rootOrgId);
        rootOrg.setFullName("中铁建");
        rootOrg.setName("中铁建");
        rootOrg.setVirtual(false);
        rootOrg.setShow(true);
        rootOrg.setProviderId(rootOrgCode);
        rootOrg.setType(1);
        rootOrg.setUniqSymbol(rootOrgId.toString());
        rootOrg.setOrder(1);

        return rootOrg;
    }
}

==> ejc-ztjpoc-api-3.0.0-20210927.025800-75-sources.jar: com/ejianc/poc/vo/OrgVO.java <==
package com.ejianc.poc.vo;

/**
 * @author CJ
 * @Description:
 * @date 2021/4/14 16:55
 */
public class OrgVO extends BaseFieldVO {

    public static final Long rootOrgId = -999999L;
    public static final String rootOrgCode = "root_org_code";
    private static final long serialVersionUID = 9162261826184960936L;

    public static OrgVO rootOrg;

    /**
     *
     * 单位全称
     */
    private String fullName;
    /**
     * 单位code
     */
    private String code;

    /**
     * 是否在组织机构路径中显示
     */
    private Boolean show;
    /**
     * 是否虚拟组织机构
     */
    private Boolean virtual;

    /**
     * 父级单位Id
     */
    private String pid;

    public String getPid() {
        return pid;
    }

    public void setPid(String pid) {
        this.pid = pid;
    }

    public String getFullName() {
        return fullName;
    }

    public void setFullName(String fullName) {
        this.fullName = fullName;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Boolean getShow() {
        return show;
    }

    public void setShow(Boolean show) {
        this.show = show;
    }

    public Boolean getVirtual() {
        return virtual;
    }

    public void setVirtual(Boolean virtual) {
        this.virtual = virtual;
    }

    public static OrgVO getRootOrg() {
        if(null != rootOrg) {
            return rootOrg;
        }

        rootOrg = new OrgVO();
        rootOrg.setCode(rootOrgCode);
        rootOrg.setId(rootOrgId);
        rootOrg.setFullName("总公司");
        rootOrg.setName("总公司");
        rootOrg.setVirtual(false);
        rootOrg.setShow(true);
        rootOrg.setProviderId(rootOrgCode);
        rootOrg.setType(1);
        rootOrg.setUniqSymbol(rootOrgId.toString());
        rootOrg.setOrder(1);

        return rootOrg;
    }
}
